summaryrefslogtreecommitdiffstats
path: root/sys/contrib/dev/acpica/executer/exutils.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/contrib/dev/acpica/executer/exutils.c')
-rw-r--r--sys/contrib/dev/acpica/executer/exutils.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/sys/contrib/dev/acpica/executer/exutils.c b/sys/contrib/dev/acpica/executer/exutils.c
index 23e39c5..d90d6ea 100644
--- a/sys/contrib/dev/acpica/executer/exutils.c
+++ b/sys/contrib/dev/acpica/executer/exutils.c
@@ -9,7 +9,7 @@
*
* 1. Copyright Notice
*
- * Some or all of this work - Copyright (c) 1999 - 2009, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2010, Intel Corp.
* All rights reserved.
*
* 2. License
@@ -144,7 +144,7 @@
static UINT32
AcpiExDigitsNeeded (
- ACPI_INTEGER Value,
+ UINT64 Value,
UINT32 Base);
@@ -334,7 +334,7 @@ AcpiExTruncateFor32bitTable (
* We are running a method that exists in a 32-bit ACPI table.
* Truncate the value to 32 bits by zeroing out the upper 32-bit field
*/
- ObjDesc->Integer.Value &= (ACPI_INTEGER) ACPI_UINT32_MAX;
+ ObjDesc->Integer.Value &= (UINT64) ACPI_UINT32_MAX;
}
}
@@ -446,17 +446,17 @@ AcpiExReleaseGlobalLock (
static UINT32
AcpiExDigitsNeeded (
- ACPI_INTEGER Value,
+ UINT64 Value,
UINT32 Base)
{
UINT32 NumDigits;
- ACPI_INTEGER CurrentValue;
+ UINT64 CurrentValue;
ACPI_FUNCTION_TRACE (ExDigitsNeeded);
/* ACPI_INTEGER is unsigned, so we don't worry about a '-' prefix */
if (Value == 0)
{
@@ -497,7 +497,7 @@ AcpiExDigitsNeeded (
void
AcpiExEisaIdToString (
char *OutString,
- ACPI_INTEGER CompressedId)
+ UINT64 CompressedId)
{
UINT32 SwappedId;
@@ -523,10 +523,10 @@ AcpiExEisaIdToString (
OutString[0] = (char) (0x40 + (((unsigned long) SwappedId >> 26) & 0x1F));
OutString[1] = (char) (0x40 + ((SwappedId >> 21) & 0x1F));
OutString[2] = (char) (0x40 + ((SwappedId >> 16) & 0x1F));
- OutString[3] = AcpiUtHexToAsciiChar ((ACPI_INTEGER) SwappedId, 12);
- OutString[4] = AcpiUtHexToAsciiChar ((ACPI_INTEGER) SwappedId, 8);
- OutString[5] = AcpiUtHexToAsciiChar ((ACPI_INTEGER) SwappedId, 4);
- OutString[6] = AcpiUtHexToAsciiChar ((ACPI_INTEGER) SwappedId, 0);
+ OutString[3] = AcpiUtHexToAsciiChar ((UINT64) SwappedId, 12);
+ OutString[4] = AcpiUtHexToAsciiChar ((UINT64) SwappedId, 8);
+ OutString[5] = AcpiUtHexToAsciiChar ((UINT64) SwappedId, 4);
+ OutString[6] = AcpiUtHexToAsciiChar ((UINT64) SwappedId, 0);
OutString[7] = 0;
}
@@ -551,7 +551,7 @@ AcpiExEisaIdToString (
void
AcpiExIntegerToString (
char *OutString,
- ACPI_INTEGER Value)
+ UINT64 Value)
{
UINT32 Count;
UINT32 DigitsNeeded;
@@ -446,17 +446,17 @@ AcpiExReleaseGlobalLock (
ACPI_FUNCTION_TRACE (ExDigitsNeeded);
- /* ACPI_INTEGER is unsigned, so we don't worry about a '-' prefix */
+ /* UINT64 is unsigned, so we don't worry about a '-' prefix */
if (Value == 0)
{
OpenPOWER on IntegriCloud